parameters:
  lescript_certs_path: /data/ssl/letsencrypt
  lescript_web_path: /opt/www/
  lescript_log: /data/log/admin-app/lescript.log

services:
  _defaults:
    autowire: true
    autoconfigure: true
    #public: false
    public: true

  App\Base\Command\:
    resource: '../src/Base/Command'
    tags: ['console.command']

  App\Base\CommandInternal\:
    resource: '../src/Base/CommandInternal'

  App\Base\Controller\:
    resource: '../src/Base/Controller/*'
    tags: ['controller.service_arguments']

  App\Base\Repository\:
    resource: '../src/Base/Repository/*'
    public: true

  App\Base\Handler\:
    resource: '../src/Base/Handler/*'

  App\Base\Handler\BoxHandler:
    arguments:
      $om: '@doctrine.orm.default_entity_manager'

  App\Base\Handler\DomainHandler:
    arguments:
      $om: '@doctrine.orm.default_entity_manager'

  App\Base\Security\:
    resource: '../src/Base/Security/*'
    exclude: '../src/Base/Security/{UsernamePasswordIPToken.php}'

  App\Base\Server\Ini: ~
  App\Base\Server\MailServerManager: ~
  App\Base\Server\System: ~
  App\Base\Mailer\Mailer: ~
  App\Base\Handler\FileSystemHandler: ~

  App\Base\Twig\HelperExtension:
    tags:
      - { name: twig.extension }

  Predis\Client: ~

  App\Base\Redis\Redis: ~
  App\Base\Redis\HostAutomaticRepository: ~
  App\Base\Redis\HostManualRepository: ~
  App\Base\Redis\KarmaRepository: ~

  App\Base\Resolver\Resolver:
    arguments:
      - '@Predis\Client'
      - 'rcache|'

  App\Base\EventSubscriber\:
    resource: '../src/Base/EventSubscriber/*'
    tags:
      - { name: doctrine.event_subscriber, connection: default }

  App\Base\Security\DovecotAuthenticator: ~

  #  App\Base\Security\DovecotAuthProvider:
  #    public: true
  #    arguments:
  #      $encoderFactory: '@security.encoder_factory'
  #      $hideUserNotFoundExceptions: '%security.authentication.hide_user_not_found%'

  #  security.authentication.provider.dao:
  #    alias: App\Base\Security\DovecotAuthProvider
  #    public: true

  #  security.user.provider.concrete.dovecot.auth.provider:
  #    alias: App\Base\Repository\BoxRepository
  #    public: true

  analogic_acme_lescript_logger:
    class: Monolog\Logger
    arguments:
      - "LEScript"
      - ['@analogic_acme_lescript_logger_handler']

  analogic_acme_lescript_logger_formatter:
    class: Monolog\Formatter\LineFormatter
    arguments:
      - "[%%datetime%%] %%channel%%.%%level_name%%: %%message%%\n"

  analogic_acme_lescript_logger_handler:
    class: Monolog\Handler\StreamHandler
    arguments:
      - '%lescript_log%'
      - 100
    calls:
      - method: setFormatter
        arguments: ['@analogic_acme_lescript_logger_formatter']

  Analogic\ACME\Lescript:
    arguments:
      - '%lescript_certs_path%'
      - '%lescript_web_path%'
      - '@analogic_acme_lescript_logger'

  App\Base\Handler\LeHandler:
    arguments:
      $logger: '@analogic_acme_lescript_logger'
      $certsPath: '%lescript_certs_path%'
      $leLogPath: '%lescript_log%'

  App\Base\Email\Alert: ~

  App\Base\Config\Config:
    calls:
      - method: importIni
        arguments:
          - '/data/server.ini'

  App\Base\LocaleListener:
    arguments:
      - '@service_container'
      - ['en', 'cs']
    tags:
      - { name: kernel.event_listener, event: kernel.request, method: onKernelRequest, priority: 100 }

  App\Base\Diagnostic\:
    resource: '../src/Base/Diagnostic'
    public: true
    # we need DNSBL for dynamic loading for check command


  App\Base\Form\:
    resource: '../src/Base/Form/*'
    tags:
      - { name: form.type }